#include "fftorder.h"

const unsigned char fftorder_32[] = {
0,16,8,24,4,20,28,12,2,18,10,26,30,14,6,22,
1,17,9,25,5,21,29,13,31,15,7,23,3,19,27,11
} ;
